@@ -33,7 +33,7 @@
 
 # future division is important to divide integers and get as
 # a result precise floating numbers (instead of truncated int)
-from __future__ import division, absolute_import, with_statement
+#from __future__ import division, absolute_import, with_statement  # unnecessary since we dropped Python 2 support, but still can be interesting if we reimplement in Cython, Cython v3 will be needed for the maths
 
 # Include the lib folder in the python import path (so that packaged modules can be easily called, such as gooey which always call its submodules via gooey parent module)
 import sys, os
@@ -190,7 +190,7 @@ def AutoGooey(fn):  # pragma: no cover
 #***********************************
 
 @AutoGooey
-def main(argv=None):
+def main(argv=None, command=None):
     if argv is None: # if argv is empty, fetch from the commandline
         argv = sys.argv[1:]
     elif isinstance(argv, _str): # else if argv is supplied but it's a simple string, we need to parse it to a list of arguments before handing to argparse or any other argument parser
@@ -209,7 +209,7 @@ WARNING: this will tamper the file you specify. Please ensure you keep a copy of
     # Use GooeyParser if we want the GUI because it will provide better widgets
     if len(argv) > 0 and (argv[0] == '--gui' and not '--ignore-gooey' in argv):  # pragma: no cover
         # Initialize the Gooey parser
-        main_parser = gooey.GooeyParser(add_help=True, description=desc, epilog=ep, formatter_class=argparse.RawTextHelpFormatter)
+        main_parser = gooey.GooeyParser(add_help=True, description=desc, epilog=ep, formatter_class=argparse.RawTextHelpFormatter, prog=command)
         # Define Gooey widget types explicitly (because type auto-detection doesn't work quite well)
         widget_dir = {"widget": "DirChooser"}
         widget_filesave = {"widget": "FileSaver"}
@@ -217,9 +217,10 @@ WARNING: this will tamper the file you specify. Please ensure you keep a copy of
         widget_text = {"widget": "TextField"}
     else: # Else in command-line usage, use the standard argparse
         # Delete the special argument to avoid unrecognized argument error in argparse
-        if '--ignore-gooey' in argv[0]: argv.remove('--ignore-gooey') # this argument is automatically fed by Gooey when the user clicks on Start
+        if '--ignore-gooey' in argv: argv.remove('--ignore-gooey') # this argument is automatically fed by Gooey when the user clicks on Start
         # Initialize the normal argparse parser
-        main_parser = argparse.ArgumentParser(add_help=True, description=desc, epilog=ep, formatter_class=argparse.RawTextHelpFormatter)
+        # Note that prog allows to change the shown calling script, it is necessary to manually set it when it is called as a subcommand (of pff.py). If None, prog will default to sys.argv[0] but with the absolute path removed.
+        main_parser = argparse.ArgumentParser(add_help=True, description=desc, epilog=ep, formatter_class=argparse.RawTextHelpFormatter, prog=command)
         # Define dummy dict to keep compatibile with command-line usage
         widget_dir = {}
         widget_filesave = {}
